@@ -1,6 +1,6 @@
 package Search::Elasticsearch::Async;
 
-our $VERSION = '6.00';
+our $VERSION = '6.80_1';
 use Search::Elasticsearch 6.00;
 use Promises 0.93 ();
 use parent 'Search::Elasticsearch';
@@ -47,7 +47,7 @@ Search::Elasticsearch::Async - Async API for Elasticsearch using Promises
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -644,11 +644,11 @@ DATA YOU WANT TO KEEP!>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
