@@ -1,6 +1,7 @@
 package Search::Elasticsearch::CxnPool::Async::Sniff;
-$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::CxnPool::Async::Sniff::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Async';
 
@@ -141,7 +142,7 @@ Search::Elasticsearch::CxnPool::Async::Sniff - An async CxnPool for connecting t
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 SYNOPSIS
 
@@ -304,11 +305,11 @@ From L<Search::Elasticsearch::Role::CxnPool>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
