@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Role::Cxn::Async;
-$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.00';
-use Moo::Role;
+$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Role::Cxn::Async::VERSION = '6.801';use Moo::Role;
 
 use Search::Elasticsearch::Util qw(new_error);
 use namespace::clean;
@@ -65,7 +66,7 @@ Search::Elasticsearch::Role::Cxn::Async - Provides common functionality to async
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -102,11 +103,11 @@ Send a sniff request to the node and return the response.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
