@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Transport::Async;
-$Search::Elasticsearch::Transport::Async::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Transport::Async::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Transport::Async::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Role::Is_Async',
     'Search::Elasticsearch::Role::Transport';
 
@@ -86,7 +87,7 @@ Search::Elasticsearch::Transport::Async - Provides async interface between the c
 
 =head1 VERSION
 
-version 6.00
+version 6.80_1
 
 =head1 DESCRIPTION
 
@@ -177,11 +178,11 @@ JSON) or using the special I<bulk> format:  C<"std"> or C<"bulk">.
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
