@@ -8,12 +8,21 @@ my $trace
     : $ENV{TRACE} eq '1' ? 'Stderr'
     :                      [ 'File', $ENV{TRACE} ];
 
-my $version = $ENV{ES_VERSION} || '';
-my $api = $version =~ /^0.90/ ? '0_90::Direct' : 'Direct';
-my $body     = $ENV{ES_BODY}     || 'GET';
-my $cxn      = $ENV{ES_CXN}      || do "default_cxn.pl" || die $!;
+unless ($ENV{CLIENT_VER}) {
+    plan skip_all => 'No $ENV{CLIENT_VER} specified';
+    exit;
+}
+unless ($ENV{ES}) {
+    plan skip_all => 'No Elasticsearch test node available';
+    exit;
+}
+
+my $api      = "$ENV{CLIENT_VER}::Direct";
+my $body     = $ENV{ES_BODY} || 'GET';
+my $cxn      = $ENV{ES_CXN} || do "default_cxn.pl" || die( $@ || $! );
 my $cxn_pool = $ENV{ES_CXN_POOL} || 'Static';
-my $timeout  = $ENV{ES_TIMEOUT}  || 30;
+my $timeout  = $ENV{ES_TIMEOUT} || 30;
+my @plugins  = split /,/, ( $ENV{ES_PLUGINS} || '' );
 our %Auth;
 
 my $es;
@@ -27,6 +36,7 @@ if ( $ENV{ES} ) {
             client           => $api,
             send_get_body_as => $body,
             request_timeout  => $timeout,
+            plugins          => \@plugins,
             %Auth
         );
         $es->ping unless $ENV{ES_SKIP_PING};
@@ -37,9 +47,16 @@ if ( $ENV{ES} ) {
     };
 }
 
-unless ($es) {
-    plan skip_all => 'No Elasticsearch test node available';
-    exit;
+unless ( $ENV{ES_SKIP_PING} ) {
+    my $version = $es->info->{version}{number};
+    my $api     = $es->api_version;
+    unless ( $api eq '0_90' && $version =~ /^0\.9/
+        || substr( $api, 0, 1 ) eq substr( $version, 0, 1 ) )
+    {
+        plan skip_all =>
+            "Tests are for API version $api but Elasticsearch is version $version\n";
+        exit;
+    }
 }
 
 return $es;
